@@ -3,14 +3,12 @@ CREATE_API_KEY = "/create-api-key"
 GET_API_KEYS = "/get-api-keys"
 DELETE_API_KEY = "/delete-api-key"
 DERIVE_API_KEY = "/derive-api-key"
-TRADE_HISTORY = "/trade-history"
+TRADES = "/trades"
 GET_ORDER_BOOK = "/book"
 GET_ORDER = "/order/"
-OPEN_ORDERS = "/open-orders"
-LARGE_ORDERS = "/large-orders"
+ORDERS = "/orders"
 POST_ORDER = "/order"
 CANCEL = "/order"
-ORDER_HISTORY = "/order-history"
 CANCEL_ALL = "/cancel-all"
 MID_POINT = "/midpoint"
 PRICE = "/price"
